# Copyright (C) 2023,2025 Ð½Ð°Ð± (nabijaczleweli@nabijaczleweli.xyz)
# Copyright (C) 2023 Alexandre Detiste (alexandre@detiste.be)
# Copyright (C) 2025 Pramod (pramodvu1502@proton.me) (only for this specfile though)
# SPDX-License-Identifier: MIT

Name:           systemd-cron
Version:        2.5.1
Release:        %{autorelease}
License:        MIT
Summary:        A systemd generator to provide (ana)cron functionality
URL:            https://github.com/systemd-cron/systemd-cron
Source0:        %{url}/archive/v%{version}.tar.gz
Conflicts:      cronie
Conflicts:      cronie-anacron
Conflicts:      crontabs
Provides:       crontabs >= 1.11
Requires:       systemd
Requires:       libmd
#Recommends:     %%{_bindir}/sendmail
BuildRequires:  gcc-c++
BuildRequires:  libmd-devel
BuildRequires:  systemd-rpm-macros

%description
A systemd generator implementing (ana)cron.
It uses systemd.timer and systemd.service under the hood.

%pre
# Prevent execution of reboot scripts on installation
touch %{_rundir}/crond.reboot

%preun
%systemd_preun cron.target

%post
%systemd_post cron.target

# To apply the /var/spool/cron and crontab group to the system on installation
%{_bindir}/systemctl reload-or-restart systemd-sysusers.service systemd-tmpfiles-setup.service

%postun
%systemd_postun_with_restart cron.target

%prep
%setup -q

%build
# Don't use the %%configure macro as this is not an autotool script
./configure \
  --with-version="%{version}" \
  --prefix="%{_prefix}" \
  --bindir="%{_bindir}" \
  --datadir="%{_datadir}" \
  --libdir="%{_libdir}" \
  --libexecdir="%{_libexecdir}" \
  --mandir="%{_mandir}" \
  --docdir="%{_docdir}" \
  --unitdir="%{_unitdir}" \
  --generatordir="%{_systemdgeneratordir}" \
  --sysusersdir="%{_sysusersdir}" \
  --enable-runparts=no \
  --enable-minutely=yes \
  --enable-quarterly=yes \
  --enable-semi_annually=yes \
  --enable-boot=no

# Disabled run-parts i.e. static single units for each granuarity level.
# Instead opting to use only the systemd-crontab-generator
# run-parts override the generator when installed
#
# Also enabled all disabled-by-default granularity levels
#
# cron.boot isn't otherwise supported in fedora, we follow that.

# Compile
%make_build

%install
%make_install

# Preparing some important directories using tmpfiles.d
mkdir -p "${RPM_BUILD_ROOT}%{_tmpfilesdir}"
SDCRONTMPFILES="${RPM_BUILD_ROOT}%{_tmpfilesdir}/systemd-cron.conf"
touch "${SDCRONTMPFILES}"

printf "%s\n" "d %{_localstatedir}/spool/cron 1730 root crontab" >> "${SDCRONTMPFILES}"
printf "%s\n" "d %{_sysconfdir}/cron.d 0600 root root" >> "${SDCRONTMPFILES}"

TIMEUNITS="minutely hourly daily weekly monthly yearly quarterly semi_annually"
for timeunit in ${TIMEUNITS}
do printf "%s\n" "d %{_sysconfdir}/cron.${timeunit} 0600 root root" >> "${SDCRONTMPFILES}"
done

# A sample crontab file
mkdir -p "${RPM_BUILD_ROOT}%{_sysconfdir}"
touch "${RPM_BUILD_ROOT}%{_sysconfdir}/crontab"
cat >> "${RPM_BUILD_ROOT}%{_sysconfdir}/crontab" <<SDCRONTABPKGSAMPLE
# /etc/crontab: system-wide crontab
# This is the main crontab used by systemd-cron
# Unlike any other crontab you don't have to run the "crontab"
# command to install the new version when you edit this file
# and files in /etc/cron.d.
# These files also have username fields, that none of the other crontabs do.
#
# See manpages crontab(1), crontab(5) and anacrontab(5) for more info
#
# Note: /etc/cron.* directories are handled separately, no run-parts here for them.

SHELL=/bin/sh
PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin

# Format of job definition:
# .---------------- minute (0 - 59)
# |  .------------- hour (0 - 23)
# |  |  .---------- day of month (1 - 31)
# |  |  |  .------- month (1 - 12) OR jan,feb,mar,apr ...
# |  |  |  |  .---- day of week (0 - 6) (Sunday=0 or 7) OR sun,mon,tue,wed,thu,fri,sat
# |  |  |  |  |
# *  *  *  *  * user-name command to be executed

# Directives like '*/5' mean "every 5 (minutes,hours,whatever)"
# Supports special directives like @daily, @monthly, etc... in place of the 1st 5 columns

# Examples:
#* * * * * root echo "minutely echo"
#@daily systemd-resolve echo "echo something daily as the systemd-resolve user"
#*/5 * */10 1-6,8-10 7 root echo "A random echoing cron"
# Above echos every 5 minutes every hour every 10 days months 1-6 and 8-10 on sundays
SDCRONTABPKGSAMPLE

# systemd preset as required by fedora
mkdir -p "${RPM_BUILD_ROOT}%{_presetdir}"
printf "%s\n" "enable cron.target" > "${RPM_BUILD_ROOT}%{_presetdir}/50-systemd-cron.preset"

%files
%license LICENSE
%doc README.md CHANGELOG
%config(noreplace) /etc/crontab

%dir %{_libexecdir}/systemd-cron
%{_bindir}/crontab
%{_libexecdir}/systemd-cron/mail_for_job
%{_libexecdir}/systemd-cron/boot_delay
%{_libexecdir}/systemd-cron/remove_stale_stamps
%attr(2755, root, crontab) %{_libexecdir}/systemd-cron/crontab_setgid
%{_systemdgeneratordir}/systemd-crontab-generator

%{_presetdir}/50-systemd-cron.preset
%{_unitdir}/cron.target
%{_unitdir}/cron-update.path
%{_unitdir}/cron-update.service
%{_unitdir}/cron-mail@.service
%{_unitdir}/systemd-cron-cleaner.service
%{_unitdir}/systemd-cron-cleaner.timer

%{_sysusersdir}/systemd-cron.conf
%{_tmpfilesdir}/systemd-cron.conf

%{_mandir}/man1/crontab.*
%{_mandir}/man5/crontab.*
%{_mandir}/man5/anacrontab.*
%{_mandir}/man7/systemd.cron.*
%{_mandir}/man8/systemd-crontab-generator.*

%changelog
%autochangelog
